@@ -2,7 +2,7 @@ package DateTime::Format::Flexible;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 use base 'DateTime::Format::Builder';
 
@@ -35,6 +35,7 @@ my $XMMXDDYYYY = qr{X(\d{1,2})X${DELIM}?(\d{1,2})${DELIM}?(\d{1,4})};
 
 my $HMSMD = [ qw( hour minute second month day ) ];
 my $HMSMDY = [ qw( hour minute second month day year ) ];
+my $HMSYMD = [ qw( hour minute second year month day ) ];
 my $HMSNSMDY = [ qw( hour minute second nanosecond month day year ) ];
 my $HMSDM = [ qw( hour minute second day month ) ];
 my $HMMDY = [ qw( hour minute month day year ) ];
@@ -59,6 +60,7 @@ my $MDHMS = [ qw( month day hour minute second ) ];
 my $MDHMSAP = [ qw( month day hour minute second ampm ) ];
 my $MYHMS = [ qw( month year hour minute second ) ];
 my $MYHMSAP = [ qw( month year hour minute second ampm ) ];
+my $MDYHM = [ qw( month day year hour minute second ) ];
 my $MDYHMS = [ qw( month day year hour minute second ) ];
 my $MDYHMAP = [ qw( month day year hour minute ampm ) ];
 my $MDYHMSAP = [ qw( month day year hour minute second ampm ) ];
@@ -111,6 +113,9 @@ my $formats =
  { length => [11..20], params => $MDYHMAP,  regex => qr{\A${MON}${DELIM}${DAY}${DELIM}${YEAR}\s$HM\s?$AMPM\z},  postprocess => [ \&_fix_ampm , \&_fix_year ] } ,
  { length => [14..22], params => $MDYHMSAP, regex => qr{\A${MON}${DELIM}${DAY}${DELIM}${YEAR}\s$HMS\s?$AMPM\z}, postprocess => [ \&_fix_ampm , \&_fix_year ] } ,
 
+ # 02/28/2014 14:30 (missing seconds)
+ { length => [14..16], params => $MDYHM,    regex => qr{\A$MMDDYYYY\s$HM\z}, postprocess => \&_set_default_seconds } ,
+
  ########################################################
  ##### Year/Month/Day
  ##### Can't have 1,2 digit years in this format, would get confused
@@ -218,10 +223,14 @@ my $formats =
  # 5:30:25 12101965
  { length => [14..16], params => $HMSMDY, regex => qr{\A${HMS}${DELIM}${MON}${DAY}${YEAR}\z}, postprocess => \&_fix_year },
  { length => [14..19], params => $HMSMDY, regex => qr{\A${HMS}${DELIM}${MMDDYYYY}\z}, postprocess => \&_fix_year },
+
+ { length => [14..19], params => $HMSYMD, regex => qr{\A${HMS}${DELIM}${YYYYMMDD}\z}, postprocess => \&_fix_year },
+
  # 5:30 pm 121065 => 2065-12-01T17:30:00
  { length => [14,18], params => $HMAPMMDDYYYY, regex => qr{\A${HM}\s${AMPM}\s${MON}${DAY}${YEAR}},postprocess => [\&_fix_ampm, \&_fix_year] },
  { length => [16,19], params => $HMAPMMDDYYYY, regex => qr{\A${HM}\s${AMPM}\s${MMDDYYYY}},postprocess => [\&_fix_ampm, \&_fix_year] },
 
+
  ########################################################
  ##### Alpha months
  # _fix_alpha changes month name to "XMX"
@@ -541,10 +550,12 @@ sub _parse_timezone
         }
     }
 
-    # search for GMT inside the string
+    # search for GMT/UTC inside the string
     # must be surrounded by spaces
     # 5:30 pm GMT 121065
-    if ( my ( $tz ) = $date =~ m{\s(GMT)\s}mx )
+    # Tue Feb 28 14:30:00 UTC 2014
+
+    if ( my ( $tz ) = $date =~ m{\s(GMT|UTC)\s}mx )
     {
         $date =~ s{\Q$tz\E}{};
         $p->{time_zone} = 'UTC';
@@ -659,6 +670,13 @@ sub _fix_ampm
     return 1;
 }
 
+sub _set_default_seconds
+{
+    my %args = @_;
+    $args{parsed}{second} = 0;
+    return 1;
+}
+
 sub _set_default_year
 {
     my %args = @_;
@@ -868,8 +886,8 @@ example:
 
 =item * C<MMYY> (optional)
 
-By default, this module parse 12/10 as December 10th of the current
-year (MM/DD).
+By default, this module will parse 12/10 as December 10th of the
+current year (MM/DD).
 
 If you want it to parse this as MM/YY instead, you can enable the
 C<MMYY> option.
